## $Id: browser.py 17020 2022-07-10 18:21:55Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""UI components for basic applicants and related components.
"""
import grok
from zope.formlib.textwidgets import BytesDisplayWidget
from zope.component import getUtility
from waeup.kofa.widgets.datewidget import (
    FriendlyDateDisplayWidget,
    FriendlyDatetimeDisplayWidget)
from waeup.kofa.applicants.pdf import PDFApplicationSlip
from waeup.kofa.applicants.browser import (
    ApplicantRegistrationPage, ApplicantsContainerPage,
    ApplicantDisplayFormPage,
    ApplicantManageFormPage,
    ApplicantEditFormPage,
    BalancePaymentAddFormPage,
    ExportPDFPaymentSlipPage,
    ApplicantBaseDisplayFormPage)
from waeup.kofa.students.interfaces import IStudentsUtils
from waeup.kofa.applicants.interfaces import IApplicantOnlinePayment
from kofacustom.nigeria.applicants.interfaces import INigeriaApplicantOnlinePayment
from kofacustom.nigeria.applicants.browser import NigeriaExportPDFPaymentSlipPage
from kofacustom.lpng.applicants.interfaces import (
    ICustomApplicant,
    ICustomApplicantOnlinePayment,
    ICustomApplicantEdit,
    )
from kofacustom.lpng.interfaces import MessageFactory as _

        
class CustomApplicantDisplayFormPage(ApplicantDisplayFormPage):
    """A display view for applicant data.
    """

    @property
    def form_fields(self):
        form_fields = grok.AutoFields(ICustomApplicant)
        form_fields['perm_address'].custom_widget = BytesDisplayWidget
        form_fields['notice'].custom_widget = BytesDisplayWidget
        if not getattr(self.context, 'student_id'):
            form_fields = form_fields.omit('student_id')
        return form_fields

class CustomPDFApplicationSlip(PDFApplicationSlip):

    @property
    def form_fields(self):
        form_fields = grok.AutoFields(ICustomApplicant)
        if not getattr(self.context, 'student_id'):
            form_fields = form_fields.omit('student_id')
        return form_fields

class CustomApplicantManageFormPage(ApplicantManageFormPage):
    """A full edit view for applicant data.
    """

    @property
    def form_fields(self):
        form_fields = grok.AutoFields(ICustomApplicant)
        if not getattr(self.context, 'student_id'):
            form_fields = form_fields.omit('student_id')
        form_fields['applicant_id'].for_display = True
        return form_fields

class CustomApplicantEditFormPage(ApplicantEditFormPage):
    """An applicant-centered edit view for applicant data.
    """

    def unremovable(self, ticket):
        return True

    @property
    def form_fields(self):
        form_fields = grok.AutoFields(ICustomApplicantEdit)
        form_fields = form_fields.omit('notice')
        if not getattr(self.context, 'student_id'):
            form_fields = form_fields.omit('student_id')
        form_fields['applicant_id'].for_display = True
        form_fields['reg_number'].for_display = True
        return form_fields
        
class CustomBalancePaymentAddFormPage(BalancePaymentAddFormPage):
    """ Page to add an online payment which can balance s previous session
    payment.
    """
    grok.require('waeup.payApplicant')
    
class CustomApplicantBaseDisplayFormPage(ApplicantBaseDisplayFormPage):

    @property
    def form_fields(self):
        form_fields = grok.AutoFields(ICustomApplicant).select(
            'applicant_id', 'reg_number', 'email')
        return form_fields

class CustomExportPDFPaymentSlipPage(NigeriaExportPDFPaymentSlipPage):
    """Deliver a PDF slip of the context.
    """
    # use IApplicantOnlinePayment alternativly
    form_fields = grok.AutoFields(INigeriaApplicantOnlinePayment).omit(
        'p_item').omit('p_option').omit('p_combi')
    form_fields['creation_date'].custom_widget = FriendlyDatetimeDisplayWidget('le')
    form_fields['payment_date'].custom_widget = FriendlyDatetimeDisplayWidget('le')

    def render(self):
        if self.payment_slip_download_warning:
            self.flash(self.payment_slip_download_warning, type='danger')
            self.redirect(self.url(self.context))
            return
        applicantview = CustomApplicantBaseDisplayFormPage(self.context.__parent__,
            self.request)
        students_utils = getUtility(IStudentsUtils)
        return students_utils.renderPDF(self,'payment_slip.pdf',
            self.context.__parent__, applicantview, note=self.note,
            omit_fields=())